summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/keyboardconfig.cpp7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/keyboardconfig.cpp b/src/keyboardconfig.cpp
index efb8f189..ff05d75b 100644
--- a/src/keyboardconfig.cpp
+++ b/src/keyboardconfig.cpp
@@ -153,10 +153,13 @@ bool KeyboardConfig::hasConflicts()
{
for (j = i, j++; j < KEY_TOTAL; j++)
{
// Allow for item shortcut and emote keys to overlap, but no other keys
if (!((((i >= KEY_SHORTCUT_1) && (i <= KEY_SHORTCUT_12)) &&
((j >= KEY_EMOTE_1) && (j <= KEY_EMOTE_12))) ||
- ((i == KEY_TOGGLE_CHAT) && (j == KEY_OK))) &&
+ ((i == KEY_TOGGLE_CHAT) && (j == KEY_OK)) ||
+ ((i == KEY_EMOTE) &&
+ (j == KEY_IGNORE_INPUT_1 || j == KEY_IGNORE_INPUT_2))) &&
(mKey[i].value == mKey[j].value)
)
{
@@ -153,10 +153,13 @@ bool KeyboardConfig::hasConflicts()
for (j = i, j++; j < KEY_TOTAL; j++)
{
- // Allow for item shortcut and emote keys to overlap, but no other keys
+ // Allow for item shortcut and emote keys to overlap
+ // as well as emote and ignore keys, but no other keys
if (!((((i >= KEY_SHORTCUT_1) && (i <= KEY_SHORTCUT_12)) &&
((j >= KEY_EMOTE_1) && (j <= KEY_EMOTE_12))) ||